#! Flux3D 11.2


#executeBatchSpy('buildGeomesh.py')

ApplicationMagneticACThermal3D(frequency='1000',
                               temperatureUnit=Unit['CELSIUS_DEGREE'],
                               coilCoefficient=CoilCoefficientAutomatic(),
                               formulationModel=MagneticACFormulationModelAutomatic(approximation=VectorPotentialApproximationNodal()),
                               scalarVariableOrder=ScalarVariableAutomaticOrder(),
                               vectorVariableOrder=VectorNodalVariableAutomaticOrder())

Symmetry['SymmetryXYplane_1'].physicalType = SymmetryNormalMagFields()


startMacroTransaction()
Symmetry['SymmetryAngleAboutZ_1'].physicalType = SymmetryTangentMagFields()

Symmetry['SymmetryAngleAboutZ_2'].physicalType = SymmetryTangentMagFields()

endMacroTransaction()

Material(name='STEEL_LF',
         propertyBH=PropertyBhTdependentNonlinearJmu(js='1.9',
         initialMur='300',
         coeffT=TemperatureCoefficientExponentiel(tau=Temperature(temperature='150',
         unit=Unit['CELSIUS_DEGREE']),
         tCurie=Temperature(temperature='760',
         unit=Unit['CELSIUS_DEGREE'])),
         temperature=Temperature(temperature='0',
         unit=Unit['CELSIUS_DEGREE'])),
         propertyJE=PropertyJeTLinearFunction(slope='0.001',
         rhoConstant='0.5E-6',
         referenceTemperature=Temperature(temperature='0',
         unit=Unit['CELSIUS_DEGREE']),
         temperature=Temperature(temperature='0',
         unit=Unit['CELSIUS_DEGREE'])),
         thermalConductivity=KtIsotropicTExponentialFunction(ka='25',
         kb='15',
         referenceTemperature=Temperature(temperature='0',
         unit=Unit['CELSIUS_DEGREE']),
         tau=Temperature(temperature='300',
         unit=Unit['CELSIUS_DEGREE'])),
         specificHeat=RhoCpTGaussFunction(energyTransition='5E8',
         rhoCpa='4E6',
         sigma='150',
         temperatureTransition=Temperature(temperature='760',
         unit=Unit['CELSIUS_DEGREE'])))

RegionVolume(name='AIR',
             magneticACThermal3D=magneticACThermal3DVolume(thermalType=Thermal3DVolumeInactive(),
             magneticType=MagneticAC3DVolumeVacuum()),
             color=Color['Turquoise'],
             visibility=Visibility['VISIBLE'])

RegionVolume(name='BRIDLE',
             magneticACThermal3D=magneticACThermal3DVolume(thermalType=Thermal3DVolumeThermalConductor(heat=VolumeHeatSourceJouleEffectValue()),
             magneticType=MagneticAC3DVolumeSolidConductor(),
             material=Material['STEEL_LF']),
             color=Color['Red'],
             visibility=Visibility['VISIBLE'])

assignRegionToVolumes(volume=[Volume[7],
                      Volume[6],
                      Volume[5]],
                      region=RegionVolume['AIR'])

assignRegionToVolumes(volume=[Volume[1]],
                      region=RegionVolume['AIR'])

assignRegionToVolumes(volume=[Volume[3],
                      Volume[4],
                      Volume[2]],
                      region=RegionVolume['BRIDLE'])

RegionVolume['AIR'].setInvisible()

RegionFace(name='LATERAL_EXC',
           magneticACThermal3D=MagneticACThermal3DFace(thermalType=Thermal3DFaceThermalExchange(coefExchange=ExchangeConstant(tExternal=Temperature(temperature='20',
           unit=Unit['CELSIUS_DEGREE']),
           value=['20',
           '0.8'])),
           magneticType=MagneticAC3DFaceInactive()),
           color=Color['Red'],
           visibility=Visibility['VISIBLE'])

RegionFace(name='FRONTAL_EXC',
           magneticACThermal3D=MagneticACThermal3DFace(thermalType=Thermal3DFaceThermalExchange(coefExchange=ExchangeConstant(tExternal=Temperature(temperature='20',
           unit=Unit['CELSIUS_DEGREE']),
           value=['20',
           '0.8'])),
           magneticType=MagneticAC3DFaceInactive()),
           color=Color['Red'],
           visibility=Visibility['VISIBLE'])

RegionFace['LATERAL_EXC'].color = Color['Magenta']

Face[1, 5, 6, 7, 8, 13, 15, 17, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33].visibility = Visibility['INVISIBLE']

Face[2, 3, 4, 6, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20].setVisible()

FaceAutomatic[13, 17, 20].assignRegion(region=RegionFace['LATERAL_EXC'])

FaceStructured[15, 19].assignRegion(region=RegionFace['FRONTAL_EXC'])

CurrentStrandedCoil(name='LF_INDUCTOR',
                    rmsModulus='9500',
                    phase='0')

CoilCircular(strandedCoil=CoilConductor['LF_INDUCTOR'],
             turnNumber='1',
             seriesOrParallel=AllInSeries(),
             coilDuplicationBySymmetriesPeriodicities=CoilDuplication(),
             coordSys=CoordSys['XYZ1'],
             center=['0',
             '0',
             '0'],
             radius='47',
             section=ComposedCoilRectangularSection(height='69',
             width='10'),
             color=Color['Turquoise'],
             visibility=Visibility['VISIBLE'])

SensorPonctual(name='TE1',
               spatialFormula='TCelsius',
               coordSys=CoordSys['CYL'],
               uvw=['30',
               '-87',
               '2.5'],
               regionVolume='BRIDLE')

SensorPonctual(name='TE2',
               spatialFormula='TCelsius',
               coordSys=CoordSys['XYZ1'],
               uvw=['25',
               '-30',
               '2'],
               regionVolume='BRIDLE')

SensorPonctual(name='TE3',
               spatialFormula='TCelsius',
               coordSys=CoordSys['XYZ1'],
               uvw=['25',
               '-30',
               '28'],
               regionVolume='BRIDLE')

SensorPonctual(name='TE4',
               spatialFormula='TCelsius',
               coordSys=CoordSys['CYL'],
               uvw=['30',
               '-87',
               '27.5'],
               regionVolume='BRIDLE')

SensorPonctual(name='TI1',
               spatialFormula='TCelsius',
               coordSys=CoordSys['CYL'],
               uvw=['25.4',
               '-87',
               '2.5'],
               regionVolume='BRIDLE')

SensorPonctual(name='TI2',
               spatialFormula='TCelsius',
               coordSys=CoordSys['CYL'],
               uvw=['25.4',
               '-48',
               '2.5'],
               regionVolume='BRIDLE')

SensorPonctual(name='TI3',
               spatialFormula='TCelsius',
               coordSys=CoordSys['CYL'],
               uvw=['25.4',
               '-48',
               '27.5'],
               regionVolume='BRIDLE')

SensorPonctual(name='TI4',
               spatialFormula='TCelsius',
               coordSys=CoordSys['CYL'],
               uvw=['25.4',
               '-87',
               '27.5'],
               regionVolume='BRIDLE')

SensorIntegralVolume(name='POWER',
                     spatialFormula='dHeatV',
                     support=SupportIntegralRegionVolume(region=[RegionVolume['BRIDLE']]))

SensorIntegralFace(name='LOSSES',
                   spatialFormula='dExchangeS',
                   support=SupportIntegralRegionFace(region=[RegionFace['FRONTAL_EXC'],
                   RegionFace['LATERAL_EXC']]))
                                                                 
saveProjectAs('Case1_Physbuilt')                                                             
                                                                 
                                                                 
